==> foundation-2.6.1.tgz: package/SocialFoursquare/SocialFoursquare.esm.js <==
import * as React from 'react';
import { EmotionIconBase } from '@emotion-icons/emotion-icon';
export const SocialFoursquare = /*#__PURE__*/React.forwardRef((props, ref) => {
  const attrs = {
    "fill": "currentColor",
    "xmlns": "http://www.w3.org/2000/svg"
  };
  return /*#__PURE__*/React.createElement(EmotionIconBase, Object.assign({
    iconAttrs: attrs,
    iconVerticalAlign: "middle",
    iconViewBox: "0 0 100 100"
  }, props, {
    ref: ref
  }), /*#__PURE__*/React.createElement("path", {
    d: "M36.217 40.748a2.651 2.651 0 00-1.878-.78 2.688 2.688 0 00-1.881.776l-6.322 6.315a2.653 2.653 0 00-.003 3.759L47.531 72.26c.429.432.986.697 1.579.762.099.016.201.02.304.02.007 0 .013 0 .019-.002l.003.002a2.687 2.687 0 001.899-.781L89.72 33.856a2.654 2.654 0 00.002-3.757l-6.312-6.322a2.626 2.626 0 00-1.881-.778 2.639 2.639 0 00-1.883.776L49.438 53.994 36.217 40.748z"
  }), /*#__PURE__*/React.createElement("path", {
    d: "M87.348 43.137L54.835 75.666a7.4 7.4 0 01-5.24 2.154l-1.443-.002-.304-.204a7.39 7.39 0 01-3.518-1.97L22.939 54.208a7.346 7.346 0 01-2.174-5.238c0-1.981.774-3.845 2.175-5.242l6.33-6.322a7.483 7.483 0 015.236-2.157c1.952 0 3.862.797 5.234 2.175l9.863 9.88 20.953-20.96-13.957-13.957c-3.694-3.693-9.738-3.693-13.432 0L12.271 43.283c-3.695 3.693-3.695 9.74 0 13.433l30.897 30.897c3.694 3.693 9.737 3.693 13.432 0l30.897-30.897c3.694-3.692 3.694-9.737 0-13.433l-.149-.146z"
  }));
});
SocialFoursquare.displayName = 'SocialFoursquare';
export const SocialFoursquareDimensions = {
  height: 100,
  width: 100
};

==> foundation-2.7.1.tgz: package/SocialFoursquare/SocialFoursquare.esm.js <==
import _extends from "@babel/runtime/helpers/extends";
import * as React from 'react';
import { EmotionIconBase } from '@emotion-icons/emotion-icon';
export var SocialFoursquare = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var attrs = {
    "fill": "currentColor",
    "xmlns": "http://www.w3.org/2000/svg"
  };
  return /*#__PURE__*/React.createElement(EmotionIconBase, _extends({
    iconAttrs: attrs,
    iconVerticalAlign: "middle",
    iconViewBox: "0 0 100 100"
  }, props, {
    ref: ref
  }), /*#__PURE__*/React.createElement("path", {
    d: "M36.217 40.748a2.651 2.651 0 00-1.878-.78 2.688 2.688 0 00-1.881.776l-6.322 6.315a2.653 2.653 0 00-.003 3.759L47.531 72.26c.429.432.986.697 1.579.762.099.016.201.02.304.02.007 0 .013 0 .019-.002l.003.002a2.687 2.687 0 001.899-.781L89.72 33.856a2.654 2.654 0 00.002-3.757l-6.312-6.322a2.626 2.626 0 00-1.881-.778 2.639 2.639 0 00-1.883.776L49.438 53.994 36.217 40.748z"
  }), /*#__PURE__*/React.createElement("path", {
    d: "M87.348 43.137L54.835 75.666a7.4 7.4 0 01-5.24 2.154l-1.443-.002-.304-.204a7.39 7.39 0 01-3.518-1.97L22.939 54.208a7.346 7.346 0 01-2.174-5.238c0-1.981.774-3.845 2.175-5.242l6.33-6.322a7.483 7.483 0 015.236-2.157c1.952 0 3.862.797 5.234 2.175l9.863 9.88 20.953-20.96-13.957-13.957c-3.694-3.693-9.738-3.693-13.432 0L12.271 43.283c-3.695 3.693-3.695 9.74 0 13.433l30.897 30.897c3.694 3.693 9.737 3.693 13.432 0l30.897-30.897c3.694-3.692 3.694-9.737 0-13.433l-.149-.146z"
  }));
});
SocialFoursquare.displayName = 'SocialFoursquare';
export var SocialFoursquareDimensions = {
  height: 100,
  width: 100
};
